==> api_compose-0.0.11.tar.gz: api_compose-0.0.11/src/api_compose/services/common/env.py <==
from functools import cache
from pathlib import Path
from typing import Any, Dict, List

import yaml

from api_compose.core.jinja.core.context import BaseJinjaContext
from api_compose.core.jinja.core.engine import JinjaEngine
from api_compose.core.settings.settings import GlobalSettingsModelSingleton
from api_compose.core.utils.dict import merge_dict
from api_compose.services.common.exceptions import YamlFileException
from api_compose.services.common.jinja import build_compile_time_jinja_engine


@cache
def get_env_vars(
) -> Dict[str, Any]:
    return load_dict_from_templated_yamls(
        yaml_file_paths=GlobalSettingsModelSingleton.get().all_env_files,
        jinja_engine=build_compile_time_jinja_engine(GlobalSettingsModelSingleton.get().discovery.manifests_folder_path)
    )


def load_dict_from_templated_yamls(
        yaml_file_paths: List[Path],
        jinja_engine: JinjaEngine,
) -> Dict[str, Any]:
    """Read Yamls, Render them, Merge them, return"""
    dict_ = {}
    for yaml_file_path in yaml_file_paths:
        if yaml_file_path.exists():
            with open(yaml_file_path, 'r') as f:
                template: str = f.read()
                rendered_str, is_success, exec = jinja_engine.set_template_by_string(
                    template).render_to_str(
                    BaseJinjaContext(
                        template=template
                    )
                )
                if not is_success:
                    raise YamlFileException(yaml_file_path) from exec
                new_dict = yaml.load(rendered_str, Loader=yaml.FullLoader)
        else:
            raise ValueError(f'Path {yaml_file_path.absolute()} does not exist!')
        # Merge
        dict_ = merge_dict(dict_, new_dict)
    return dict_

==> api_compose-0.0.12.tar.gz: api_compose-0.0.12/src/api_compose/services/common/env.py <==
from functools import cache
from pathlib import Path
from typing import Any, Dict, List

import yaml

from api_compose.core.jinja.core.context import BaseJinjaContext
from api_compose.core.jinja.core.engine import JinjaEngine
from api_compose.core.settings.settings import GlobalSettingsModelSingleton
from api_compose.core.utils.dict import merge_dict
from api_compose.services.common.exceptions import YamlFileException
from api_compose.services.common.jinja import build_env_file_jinja_engine


@cache
def get_env_vars(
) -> Dict[str, Any]:
    return load_dict_from_templated_yamls(
        yaml_file_paths=GlobalSettingsModelSingleton.get().all_env_files,
        jinja_engine=build_env_file_jinja_engine(
        )
    )


def load_dict_from_templated_yamls(
        yaml_file_paths: List[Path],
        jinja_engine: JinjaEngine,
) -> Dict[str, Any]:
    """Read Yamls, Render them, Merge them, return"""
    dict_ = {}
    for yaml_file_path in yaml_file_paths:
        if yaml_file_path.exists():
            with open(yaml_file_path, 'r') as f:
                template: str = f.read()
                rendered_str, is_success, exec = jinja_engine.set_template_by_string(
                    template).render_to_str(
                    BaseJinjaContext(
                        template=template
                    )
                )
                if not is_success:
                    raise YamlFileException(yaml_file_path) from exec
                new_dict = yaml.load(rendered_str, Loader=yaml.FullLoader)
        else:
            raise ValueError(f'Path {yaml_file_path.absolute()} does not exist!')
        # Merge
        dict_ = merge_dict(dict_, new_dict)
    return dict_
